==> reverie_dreams-0.4.3%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/block/entity/CustomChestBlockEntity.java <==
package cc.thonly.reverie_dreams.block.entity;

import lombok.Getter;
import net.minecraft.class_11368;
import net.minecraft.class_11372;
import net.minecraft.class_1262;
import net.minecraft.class_1277;
import net.minecraft.class_1278;
import net.minecraft.class_1657;
import net.minecraft.class_1799;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_2586;
import net.minecraft.class_2680;
import org.jetbrains.annotations.Nullable;

import java.util.stream.IntStream;

@Getter
public class CustomChestBlockEntity extends class_2586 implements class_1278 {
    private class_1277 inventory = new class_1277(27);

    public CustomChestBlockEntity(class_2338 pos, class_2680 state) {
        super(ModBlockEntities.CUSTOM_CHEST_BLOCK_ENTITY, pos, state);
    }

    @Override
    protected void method_11014(class_11368 view) {
        super.method_11014(view);
        this.inventory = new class_1277(27);
        class_1262.method_5429(view, this.inventory.field_5828);
    }

    @Override
    protected void method_11007(class_11372 view) {
        super.method_11007(view);
        class_1262.method_5426(view, this.inventory.field_5828);
    }

    @Override
    public int method_5439() {
        return 27;
    }

    @Override
    public boolean method_5442() {
        return this.inventory.method_5442();
    }

    @Override
    public class_1799 method_5438(int slot) {
        return this.inventory.method_5438(slot);
    }

    @Override
    public class_1799 method_5434(int slot, int amount) {
        return this.inventory.method_5434(slot, amount);
    }

    @Override
    public class_1799 method_5441(int slot) {
        return this.inventory.method_5441(slot);
    }

    @Override
    public void method_5447(int slot, class_1799 stack) {
        this.inventory.method_5447(slot, stack);
    }

    @Override
    public boolean method_5443(class_1657 player) {
        return this.inventory.method_5443(player);
    }

    @Override
    public int[] method_5494(class_2350 side) {
        return IntStream.range(0, this.method_5439()).toArray();
    }

    @Override
    public boolean method_5492(int slot, class_1799 stack, @Nullable class_2350 dir) {
        return true;
    }

    @Override
    public boolean method_5493(int slot, class_1799 stack, class_2350 dir) {
        return true;
    }

    @Override
    public void method_5448() {
        this.inventory.method_5448();
    }
}

==> reverie_dreams-0.4.6%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/block/entity/CustomChestBlockEntity.java <==
package cc.thonly.reverie_dreams.block.entity;

import lombok.Getter;
import net.minecraft.class_11368;
import net.minecraft.class_11372;
import net.minecraft.class_1262;
import net.minecraft.class_1277;
import net.minecraft.class_1278;
import net.minecraft.class_1657;
import net.minecraft.class_1799;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_2586;
import net.minecraft.class_2680;
import org.jetbrains.annotations.Nullable;

import java.util.stream.IntStream;

@Getter
public class CustomChestBlockEntity extends class_2586 implements class_1278 {
    private class_1277 inventory = new class_1277(27);

    public CustomChestBlockEntity(class_2338 pos, class_2680 state) {
        super(RDBlockEntityTypes.CUSTOM_CHEST_BLOCK_ENTITY, pos, state);
    }

    @Override
    protected void method_11014(class_11368 view) {
        super.method_11014(view);
        this.inventory = new class_1277(27);
        class_1262.method_5429(view, this.inventory.field_5828);
    }

    @Override
    protected void method_11007(class_11372 view) {
        super.method_11007(view);
        class_1262.method_5426(view, this.inventory.field_5828);
    }

    @Override
    public int method_5439() {
        return 27;
    }

    @Override
    public boolean method_5442() {
        return this.inventory.method_5442();
    }

    @Override
    public class_1799 method_5438(int slot) {
        return this.inventory.method_5438(slot);
    }

    @Override
    public class_1799 method_5434(int slot, int amount) {
        return this.inventory.method_5434(slot, amount);
    }

    @Override
    public class_1799 method_5441(int slot) {
        return this.inventory.method_5441(slot);
    }

    @Override
    public void method_5447(int slot, class_1799 stack) {
        this.inventory.method_5447(slot, stack);
    }

    @Override
    public boolean method_5443(class_1657 player) {
        return this.inventory.method_5443(player);
    }

    @Override
    public int[] method_5494(class_2350 side) {
        return IntStream.range(0, this.method_5439()).toArray();
    }

    @Override
    public boolean method_5492(int slot, class_1799 stack, @Nullable class_2350 dir) {
        return true;
    }

    @Override
    public boolean method_5493(int slot, class_1799 stack, class_2350 dir) {
        return true;
    }

    @Override
    public void method_5448() {
        this.inventory.method_5448();
    }
}
